@@ -16,7 +16,7 @@ class MermaidPrivate:
         return self.insert_code(body, code, exists)
 
     def journey(self, title):
-        return f'  journey\n    title {title}'
+        return f'journey\ntitle {title}'
 
     def insert_code(self, body: str, mermaid_code: str, replace=True) -> str:
         if replace:
@@ -33,9 +33,9 @@ class MermaidPrivate:
         return self.journey(title), False
 
     def dict2section(self, section: str, steps: Dict[str, str], who: str) -> str:
-        section_str = f'    section {section}\n'
+        section_str = f'section {section}\n'
         for step, value in steps.items():
-            section_str += f'      {step}: {value}: {who}\n'
+            section_str += f'{step}: {value}: {who}\n'
         return section_str
     
     def append2mermaid(self, mermaid: str, data: str) -> str:
@@ -151,14 +151,15 @@ class GitIssuePublisher(Publisher):
             "\n**Code Vulnerability:**\n",
             f"- **Score:** {data['codeVulnerability']['score']} {data['codeVulnerability']['emoji']}",
             f"  *{data['codeVulnerability']['comment']}*\n",
-            "\n**SOLID Principles Analysis:**\n"
+            "\n**SOLID Principles Analysis:**\n",
+            "| Principle            | Score | Comment |\n",
+            "|----------------------|-------|---------|\n"
         ]
 
         for principle, details in data['codeSOLID'].items():
-            report.append(f"- **{principle.replace('_', ' ').title()}**")
-            report.append(f"  - **Score:** {details['score']} {details['emoji']}")
-            report.append(f"  *{details['comment']}*\n")
-
+            report.append(
+                f"| {principle.replace('_', ' ').title()} | {details['score']} {details['emoji']} | *{details['comment']}* |"
+            )
 
         return '\n'.join(report)
 
@@ -172,7 +173,7 @@ class GitIssuePublisher(Publisher):
         """
         mermaid = MermaidPrivate()
         data = mermaid.dict2section(self.sha, scores, self.user)
-        return mermaid.generate_journey("#Scores History", data, existing_body)
+        return mermaid.generate_journey("Scores History", data, existing_body)
 
     
 class WebPublisher(Publisher):
